# ATS 

## Contributing

ATS is an open source project. We welcome contributions via pull
requests as well as questions, feature requests, or bug reports via
issues. Contact our team at dawson6@llnl.gov with any questions. Please also refer
to our [Code Of Conduct](CODE_OF_CONDUCT.md).

If you are not a developer at LLNL, you wont have permission to
push new branches to the repository. First, you should create a fork.
This will create your copy of the ATS repository and ensure you can
push your changes up to GitHub and create PRs. 

Create your branches off the repo:main branch. The branch name
will be of these formats:

    feature/username/short-feature-description
    bugfix/username/short-feature-description
